<?php

//mb_internal_encoding("UTF-8");
date_default_timezone_set('Asia/Tokyo');

$config = array(
	'version'		=> '2011.07.20',

	'litephp_path'	=> './inc/Lite.php',	// Lite.phpのpath
	'cache_dir'		=> './cache/',			// cacheディレクトリのpath
	'cache_time'	=> 60*10,				// cacheの有効時間(秒単位)

	'shd_path'		=> './inc/simple_html_dom.php'
);


$url[0] = 'http://nagaokamatsuri.com/pnavi/';
$url[2] = $url[0] . 'traffic2.html';
$url[3] = $url[0] . 'traffic3.html';

//日付の設定
$day = 0;

if( isset( $_GET['day'] ) ) {
	$day = (int) $_GET['day'];
}

if( $day != 2 && $day != 3 ) {
	$mktime = mktime( 0, 0, 0, 8, 3, 2011 );
	if( time() < $mktime ) {
		$day = 2;
	} else {
		$day = 3;
	}
}

$config['url']		= $url[$day];
$config['cache_id']	= $day;
$config['day']		= $day;

$json = get_json();

/*
echo '<pre>';
var_dump( json_decode( $json, true ) );
echo '</pre>';
*/

header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=utf-8");
//header("Content-Type: text/javascript; charset=utf-8"); 

echo $json;


/**
 * jsonデータを生成する
 * @param	none
 * @return	string $encoded_data
 */
function get_json() {

	global $config;

	$cacheLite = get_CacheLiteObject();
	//キャッシュを取得
	$encoded_data = $cacheLite->get( $config['cache_id'] );
	//キャッシュがない or 期限切れの場合は新たに生成
	if ( !$encoded_data ) {
		$data = get_parkingStatus();
		$encoded_data = json_encode( $data );
		if( $data['status'] == 'OK' ) {
			$cacheLite->save( $encoded_data, $config['cache_id'] );
		}
	}

	return $encoded_data;
}


/**
 * 駐車場情報の配列を生成する
 * @param	none
 * @return	array $result
 */
function get_parkingStatus() {

	global $config, $places;

	$result = array(
		'version'			=> $config['version'],
		'status'			=> '',
		'day'				=> $config['day'],
		'generated_date'	=> date("Y/m/d H:i:s")
	);

	$mktime = mktime( 0, 0, 0, 8, 4, 2011 );
	if( time() > $mktime ) {
		$result['status'] = 'Nagaoka Matsuri 2011 is over! See you next year!';
		return $result;
	}

	$html = file_get_contents( $config['url'] );
	if( !$html ) {
		$result['status'] = 'File Read Error';
		return $result;
	}

	$html = mb_convert_encoding( $html, "UTF-8", "SJIS" );

	$regexp = '/var marker(?P<id>(\d)+)[\n ]*=.*markerImg(?P<status>\d).*\}\);/sU';
	preg_match_all( $regexp, $html, $match );

	$array_status = array_combine( $match['id'], $match['status'] );
	$array_status_str = array();

	foreach( $array_status as $key => $status ) {
		$status = (int) $status;
		switch ( $status ) {
			case 1: $str = '空車あり'; break;
			case 2: $str = '残りわずか'; break;
			case 3: $str = '満車'; break;
			default: $str = '閉';
		}
		$array_status_str[$key] = $str;
	}

	// http://simplehtmldom.sourceforge.net/manual.htm
	include_once( $config['shd_path'] );

	$html = str_get_html( $html );
	$rs = $html->find('#traffic_box5 tr');

	$array_places = array();

	foreach( $rs as $r ) {
		// id
		$src = $r->find('td a', 0)->getAttribute('href');
		$regexp = '/ParkingInfo(\d+)\(\);/';
		preg_match( $regexp, $src, $match );
		$id = (int) $match[1];

		// name
		$a['name'] = trim( h( $r->find('td a', 0)->plaintext ) );

		//updatetime
		$src = $r->find('td', 0)->plaintext;
		$regexp = '/\d{2}:\d{2}:\d{2}/';
		preg_match( $regexp, $src, $match );
		$a['updatetime'] = $match[0];

		//status
		$a['status'] = (int) $array_status[$id];

		// status_str
		$a['status_str'] = $array_status_str[$id];
//		$a['status_str'] = trim( h( $r->find('th', 0)->plaintext ) );

		$array_places[$id] = $a;
	}

	$result['places'] = $array_places;
	$result['status'] = 'OK';

	return $result;
}


/**
 * キャッシュオブジェクトを生成する
 * @param	none
 * @return	object $obj
 */
function get_CacheLiteObject() {

	global $config;
	
	$options = array(
		'cacheDir' => $config['cache_dir'],
		'lifeTime' => $config['cache_time']
	);
	include_once( $config['litephp_path'] );
	$obj = new Cache_Lite( $options );
	return $obj;
}


/**
 * 文字列をアレするアレ
 * @param	string $str
 * @return	string $str
 */
function h( $str ) {
	return htmlspecialchars( $str, ENT_QUOTES, 'UTF-8' );
}

?>
